# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["VideoUpscaleCreateResponse"]


class VideoUpscaleCreateResponse(BaseModel):
    id: str
    """The ID of the newly created task."""
